/*
 * [AlbertaFamilyDay.java]
 *
 * Summary: Calculate when Alberta Family day occurs.
 *
 * Copyright: (c) 2005-2017 Roedy Green, Canadian Mind Products, http://mindprod.com
 *
 * Licence: This software may be copied and used freely for any purpose but military.
 *          http://mindprod.com/contact/nonmil.html
 *
 * Requires: JDK 1.8+
 *
 * Created with: JetBrains IntelliJ IDEA IDE http://www.jetbrains.com/idea/
 *
 * Version History:
 *  2.4 2005-07-27 added Parents' Day and Alberta family day
 */
package com.mindprod.holidays;

import com.mindprod.common18.BigDate;

/**
 * Calculate when Alberta Family day occurs.
 *
 * @author Roedy Green, Canadian Mind Products
 * @version 2.4 2005-07-27 added Parents' Day and Alberta family day
 * @since 2005-07-27
 */
public final class AlbertaFamilyDay extends HolInfo
    {
    /**
     * @inheritDoc
     */
    public String getAuthority()
        {
        return "";
        }

    /**
     * @inheritDoc
     */
    public int getFirstYear( int base )
        {
        return 1900;
        }

    /**
     * @inheritDoc
     */
    public String getName()
        {
        return "Alberta Family Day";
        }

    /**
     * @inheritDoc
     */
    public String getRule()
        {
        return "Third Monday in February.";
        }

    /**
     * @inheritDoc
     */
    public int when( int year, boolean shift, int base )
        {
        if ( !isYearValid( year, base ) )
            {
            return BigDate.NULL_ORDINAL;
            }
        return BigDate.ordinalOfnthXXXDay( 3/* third */, BigDate.MONDAY, year, BigDate.FEB );
        } // end when.
    }
