/*
 * [BCFamilyDay.java]
 *
 * Summary: Calculate when BC Family day occurs.
 *
 * Copyright: (c) 2013-2017 Roedy Green, Canadian Mind Products, http://mindprod.com
 *
 * Licence: This software may be copied and used freely for any purpose but military.
 *          http://mindprod.com/contact/nonmil.html
 *
 * Requires: JDK 1.8+
 *
 * Created with: JetBrains IntelliJ IDEA IDE http://www.jetbrains.com/idea/
 *
 * Version History:
 *  1.0 2013-02-10 initial version
 */
package com.mindprod.holidays;

import com.mindprod.common18.BigDate;

/**
 * Calculate when BC Family day occurs.
 *
 * @author Roedy Green, Canadian Mind Products
 * @version 1.0 2013-02-10 initial version
 * @since 2013-02-10
 */
public final class BCFamilyDay extends HolInfo
    {
    /**
     * @inheritDoc
     */
    public String getAuthority()
        {
        return "http://www.vancouversun.com/travel/adds+Family+holiday+second+Monday+February/6690732/story.html";
        }

    /**
     * @inheritDoc
     */
    public int getFirstYear( int base )
        {
        return 2013;
        }

    /**
     * @inheritDoc
     */
    public String getName()
        {
        return "BC Family Day";
        }

    /**
     * @inheritDoc
     */
    public String getRule()
        {
        return "Second Monday in February.";
        }

    /**
     * @inheritDoc
     */
    public int when( int year, boolean shift, int base )
        {
        if ( !isYearValid( year, base ) )
            {
            return BigDate.NULL_ORDINAL;
            }
        return BigDate.ordinalOfnthXXXDay( 2/* second */, BigDate.MONDAY, year, BigDate.FEB );
        } // end when.
    }
