/*
 * [CongressSessionStartDay.java]
 *
 * Summary: calculate when US Congress session starts.
 *
 * Copyright: (c) 1999-2017 Roedy Green, Canadian Mind Products, http://mindprod.com
 *
 * Licence: This software may be copied and used freely for any purpose but military.
 *          http://mindprod.com/contact/nonmil.html
 *
 * Requires: JDK 1.8+
 *
 * Created with: JetBrains IntelliJ IDEA IDE http://www.jetbrains.com/idea/
 *
 * Version History:
 *  4.2 2008-12-03 add World AIDS day
 */
package com.mindprod.holidays;

import com.mindprod.common18.BigDate;

/**
 * calculate when US Congress session starts.
 *
 * @author Roedy Green, Canadian Mind Products
 * @version 4.2 2008-12-03 add World AIDS day
 * @since 1999
 */
public final class CongressSessionStartDay extends HolInfo
    {
    /**
     * @inheritDoc
     */
    public String getAuthority()
        {
        return "http://en.wikipedia.org/wiki/United_States_Congress";
        }

    /**
     * @inheritDoc
     */
    public int getFirstYear( int base )
        {
        return 1789;
        }

    /**
     * @inheritDoc
     */
    public String getName()
        {
        return "US Congressional Start Day";
        }

    /**
     * @inheritDoc
     */
    public String getRule()
        {
        return "noon, January 3, in odd years.";
        }

    /**
     * @inheritDoc
     */
    public int when( int year, boolean shift, int base )
        {
        if ( !isYearValid( year, base ) )
            {
            return BigDate.NULL_ORDINAL;
            }
        if ( year % 2 != 1 )
            {
            return BigDate.NULL_ORDINAL;
            }
        int ordinal;
        ordinal = BigDate.toOrdinal( year, 1, 3 );
        //     No evidence Sunday start shifts to Monday
        //     if ( BigDate.dayOfWeek( ordinal ) == 0 )
        //           {
        //            /* sunday shift to Monday */
        //            ordinal++;
        //            }
        return shiftSatToFriSunToMon( ordinal, shift );
        } // end when.
    }
