/*
 * [MothersDay.java]
 *
 * Summary: calculate when Mother's day occurs.
 *
 * Copyright: (c) 1999-2017 Roedy Green, Canadian Mind Products, http://mindprod.com
 *
 * Licence: This software may be copied and used freely for any purpose but military.
 *          http://mindprod.com/contact/nonmil.html
 *
 * Requires: JDK 1.8+
 *
 * Created with: JetBrains IntelliJ IDEA IDE http://www.jetbrains.com/idea/
 *
 * Version History:
 *  4.2 2008-12-03 add World AIDS day
 */
package com.mindprod.holidays;

import com.mindprod.common18.BigDate;

/**
 * calculate when Mother's day occurs.
 *
 * @author Roedy Green, Canadian Mind Products
 * @version 4.2 2008-12-03 add World AIDS day
 * @since 1999
 */
public final class MothersDay extends HolInfo
    {
    /**
     * @inheritDoc
     */
    public String getAuthority()
        {
        return "";
        }

    /**
     * @inheritDoc
     */
    public int getFirstYear( int base )
        {
        return 1907;
        }

    /**
     * @inheritDoc
     */
    public String getName()
        {
        return "Mother\u2019s Day";
        }

    /**
     * @inheritDoc
     */
    public String getRule()
        {
        return "Second Sunday in May.";
        }

    /**
     * @inheritDoc
     */
    public int when( int year, boolean shift, int base )
        {
        if ( !isYearValid( year, base ) )
            {
            return BigDate.NULL_ORDINAL;
            }
        return shiftSatToFriSunToMon( BigDate.ordinalOfnthXXXDay( 2, BigDate.SUNDAY, year, BigDate.MAY ),
                shift );
        } // end when.
    }
