/*
 * [SorryDay.java]
 *
 * Summary: calculate when Sorry Day occurs in Australia.
 *
 * Copyright: (c) 2014-2017 Roedy Green, Canadian Mind Products, http://mindprod.com
 *
 * Licence: This software may be copied and used freely for any purpose but military.
 *          http://mindprod.com/contact/nonmil.html
 *
 * Requires: JDK 1.8+
 *
 * Created with: JetBrains IntelliJ IDEA IDE http://www.jetbrains.com/idea/
 *
 * Version History:
 *  1.0 2014-10-05 initial version
 */
package com.mindprod.holidays;

import com.mindprod.common18.BigDate;

/**
 * calculate when Sorry Day occurs in Australia.
 * <p/>
 * In memory of the atrocities of the residential schools.
 *
 * @author Roedy Green, Canadian Mind Products
 * @version 1.0 2014-10-05 initial version
 * @since 2014
 */
public final class SorryDay extends HolInfo
    {
    /**
     * @inheritDoc
     */
    public String getAuthority()
        {
        return "http://en.wikipedia.org/wiki/National_Sorry_Day";
        }

    /**
     * @inheritDoc
     */
    public int getFirstYear( int base )
        {
        return 1997;
        }

    /**
     * @inheritDoc
     */
    public String getName()
        {
        return "Sorry Day";
        }

    /**
     * @inheritDoc
     */
    public String getRule()
        {
        return "May 26.";
        }

    /**
     * @inheritDoc
     */
    public int when( int year, boolean shift, int base )
        {
        if ( !isYearValid( year, base ) )
            {
            return BigDate.NULL_ORDINAL;
            }
        return shiftSatToFriSunToMon( BigDate.toOrdinal( year, 5, 26 ), shift );
        } // end when.
    }
