/*
 * [UtahPioneerDay.java]
 *
 * Summary: calculate when the Utah Pioneer Day occurs.
 *
 * Copyright: (c) 1999-2017 Roedy Green, Canadian Mind Products, http://mindprod.com
 *
 * Licence: This software may be copied and used freely for any purpose but military.
 *          http://mindprod.com/contact/nonmil.html
 *
 * Requires: JDK 1.8+
 *
 * Created with: JetBrains IntelliJ IDEA IDE http://www.jetbrains.com/idea/
 *
 * Version History:
 *  4.2 2008-12-03 add World AIDS day
 */
package com.mindprod.holidays;

import com.mindprod.common18.BigDate;

/**
 * calculate when the Utah Pioneer Day occurs.
 *
 * @author Roedy Green, Canadian Mind Products
 * @version 4.2 2008-12-03 add World AIDS day
 * @since 1999
 */
public final class UtahPioneerDay extends HolInfo
    {
    /**
     * @inheritDoc
     */
    public String getAuthority()
        {
        return "Paul Hill <phill@myriad.com>";
        }

    /**
     * @inheritDoc
     */
    public int getFirstYear( int base )
        {
        return 1847;
        }

    /**
     * @inheritDoc
     */
    public String getName()
        {
        return "Utah Pioneer Day";
        }

    /**
     * @inheritDoc
     */
    public String getRule()
        {
        return "Always July 24";
        }
    // All Utah state employees and nearly all commercial
    // employees get the day off.
    // Pioneer Day is to celebrate the Mormon Pioneers
    // invading the area. The 24th is the day their leader
    // old Brigham Young himself come into the Salt
    // Lake Valley and is quoted as saying 'This is the Place."
    // first celebrated ??? Date of trek was 1847.

    /**
     * @inheritDoc
     */
    public int when( int year, boolean shift, int base )
        {
        if ( !isYearValid( year, base ) )
            {
            return BigDate.NULL_ORDINAL;
            }
        return shiftSatToFriSunToMon( BigDate.toOrdinal( year, 7, 24 ), shift );
        } // end when.
    }
